#[repr(u8)]pub enum DegradationDirection {
Up = 0,
Down = 1,
}Variants
Up = 0
The degradation of the resource is indicated by an upwards moving/increasing value
Down = 1
The degradation of the resource is indicated by a downwards moving/decreasing value
Implementations